﻿using Syncfusion.UI.Xaml.Schedule;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Globalization;
using System.IO;
using System.Linq;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace ScheduleContextMenuOverrided_WinRT
{
    public sealed partial class MainPage : Page, INotifyPropertyChanged
    {

        #region constructor
        public MainPage()
        {
            this.InitializeComponent();
            //this.typeCmb.ItemsSource = Enum.GetValues(typeof(ScheduleType));
            //this.typeCmb.SelectedIndex = 1;
            Binding visdatecoll = new Binding();
            visdatecoll.Source = this;
            visdatecoll.Path = new PropertyPath("CurrentDate");
            visdatecoll.Mode = BindingMode.TwoWay;
            this.schedule1.SetBinding(SfSchedule.VisibleDatesProperty, visdatecoll);
            this.DataContext = this;
        }
        #endregion

        #region Properties

        int _dayCount = 1;
        int _weekDaysCount = 7;
        int _monthDaysCount = 30;

        ObservableCollection<DateTime> _currentDate;
        public ObservableCollection<DateTime> CurrentDate
        {
            get { return _currentDate; }
            set
            {
                _currentDate = value;
                this.RaisePropertyChanged("CurrentDate");
            }
        }


        #endregion

        #region Events

        public event PropertyChangedEventHandler PropertyChanged;

        public void RaisePropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        private void leftArrow_Click_1(object sender, RoutedEventArgs e)
        {
            switch (this.schedule1.ScheduleType)
            {
                case ScheduleType.Day:
                    {
                        this.CurrentDate[0] = this.CurrentDate[0].SubractDays(_dayCount);
                        break;
                    }
                case ScheduleType.Week:
                case ScheduleType.WorkWeek:
                case ScheduleType.TimeLine:
                    {
                        if (this.CurrentDate.Count > 1)
                        {
                            this.CurrentDate[0] = this.CurrentDate[0].SubractDays(_weekDaysCount);
                        }
                        else
                        {
                            this.CurrentDate[0] = this.CurrentDate[0].SubractDays(_dayCount);
                        };
                        break;
                    }
                case ScheduleType.Month:
                    {
                        this.CurrentDate[0] = this.CurrentDate[0].SubractDays(_monthDaysCount);
                        break;
                    }
            }
            this.schedule1.MoveToDate(this.CurrentDate[0]);
        }

        private void rightArrow_Click_1(object sender, RoutedEventArgs e)
        {
            switch (this.schedule1.ScheduleType)
            {
                case ScheduleType.Day:
                    {
                        this.CurrentDate[0] = this.CurrentDate[0].AddDays(_dayCount);
                        break;
                    }
                case ScheduleType.Week:
                case ScheduleType.WorkWeek:
                case ScheduleType.TimeLine:
                    {
                        if (this.CurrentDate.Count > 1)
                        {
                            this.CurrentDate[0] = this.CurrentDate[0].AddDays(_weekDaysCount);
                        }
                        else
                        {
                            this.CurrentDate[0] = this.CurrentDate[0].AddDays(_dayCount);
                        }
                        break;
                    }
                case ScheduleType.Month:
                    {
                        this.CurrentDate[0] = this.CurrentDate[0].AddDays(_monthDaysCount);
                        break;
                    }
            }
            this.schedule1.MoveToDate(this.CurrentDate[0]);
        }

        private void schedule1_Loaded_1(object sender, RoutedEventArgs e)
        {
            //To hide the Default previous and Next buttons of SfSchedule in the sample level
            SfSchedule schedule = sender as SfSchedule;
            var _prevButton = VisualTreeHelper.GetChild(VisualTreeHelper.GetChild(VisualTreeHelper.GetChild(schedule, 0), 0), 7) as Button;
            var _nextButton = VisualTreeHelper.GetChild(VisualTreeHelper.GetChild(VisualTreeHelper.GetChild(schedule, 0), 0), 8) as Button;
            _prevButton.Height = 0;
            _nextButton.Height = 0; ;
        }

        #endregion

    }

    #region DateTimeConverter
    
    
    public class DateTimeConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            CultureInfo currentCulture = CultureInfo.CurrentCulture;
            var selectedDates = (ObservableCollection<DateTime>)value;
            if (selectedDates == null || selectedDates.Count <= 0)
            {
                return null;
            }
            var firstDate = selectedDates.OrderByDescending(x => x).Last();
            var lastDate = selectedDates.OrderByDescending(x => x).First();
            string result;
            if (selectedDates.Count <= 7)
            {
                if (firstDate.Month == lastDate.Month && firstDate.Year == lastDate.Year)
                    result = currentCulture.DateTimeFormat.GetMonthName(currentCulture.Calendar.GetMonth(firstDate)) + ", " + lastDate.Year;
                else if (firstDate.Year == lastDate.Year)
                    result = currentCulture.DateTimeFormat.GetMonthName(currentCulture.Calendar.GetMonth(firstDate)) + " - " + currentCulture.DateTimeFormat.GetMonthName(currentCulture.Calendar.GetMonth(lastDate)) + ", " + lastDate.Year;
                else
                    result = currentCulture.DateTimeFormat.GetMonthName(currentCulture.Calendar.GetMonth(firstDate)) + " " + firstDate.Year + " - " + currentCulture.DateTimeFormat.GetMonthName(currentCulture.Calendar.GetMonth(lastDate)) + ", " + lastDate.Year;
            }
            else
            {
                var month = currentCulture.DateTimeFormat.GetMonthName(currentCulture.Calendar.GetMonth(selectedDates[selectedDates.Count / 2].Date));
                result = month + ", " + selectedDates[selectedDates.Count / 2].Year;
            }
            return result;
        }

        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            return null;
        }
    }

  #endregion
}
